<?php

namespace EventPortal\AuthPassword\Providers;

use EventPortal\AuthPassword\Observers\UserObserver;
use Illuminate\Support\ServiceProvider;

class AuthPasswordServiceProvider extends ServiceProvider
{
    /** @var string */
    protected $root = __DIR__.'/../..';

    /** @var string */
    protected $namespace = 'EventPortal\AuthPassword\Http\Controllers';

    /** @var array<string> */
    protected $tags = [
        'auth-password',
    ];

    public function boot(): void
    {
        $this->loadRoutesFrom("{$this->root}/routes/routes.php");

        $this->loadMigrationsFrom("{$this->root}/database/migrations");

        $this->publishes([
            "{$this->root}./database/migrations" => database_path('migrations'),
        ], $this->tags);

        $this->publishes([
            "{$this->root}/config/auth-password.php" => config_path('auth-password.php'),
        ], $this->tags);

        $this->loadViewsFrom("{$this->root}/views/emails", 'auth-password');

        $this->publishes([
            "{$this->root}/views/emails" => resource_path('views/vendor/event-portal/emails/auth-password'),
        ], $this->tags);

        // phpcs:disable SlevomatCodingStandard.ControlStructures.EarlyExit
        if (class_exists(config('auth.providers.users.model'))) {
            config('auth.providers.users.model')::observe(UserObserver::class);
        }
        // phpcs:enable
    }

    public function register(): void
    {
        $this->mergeConfigFrom("{$this->root}/config/auth-password.php", 'auth-password');
    }
}
